| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
GHC.Debug.Convention
Synopsis
Documentation
socketDirectory :: IO FilePath Source #
The default socket directory in which to place unix domain sockets in ghc-debug-stub.
| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
GHC.Debug.Convention
socketDirectory :: IO FilePath Source #
The default socket directory in which to place unix domain sockets in ghc-debug-stub.